@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.210';
+our $VERSION = '0.211';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-version 0.210
+version 0.211
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ please get in contact if you're using this, or wait for version 1.000.
 
 <p>Basic rendering:</p>
 <p><img src="http://tickit.perlsite.co.uk/cpan-screenshot/tickit-widget-table-paged1.gif" alt="Paged table widget in action" width="430" height="306"></p>
-<p>Adapter updating dynamically, styled columns, deferred loadig:</p>
+<p>Adapter updating dynamically, styled columns, deferred loading:</p>
 <p><img src="http://tickit.perlsite.co.uk/cpan-screenshot/tickit-widget-table-paged2.gif" alt="Paged table widget in action" width="539" height="315"></p>
 
 =end HTML
@@ -707,6 +707,7 @@ sub render_header {
 	$rect = $rect->intersect($self->header_rect)
 		or return $self;
 
+	$rb->eraserect($rect);
 	$rb->goto(0, 0);
 	for my $col (0..$#{$self->{columns}}) {
 		my $def = $self->{columns}[$col];
@@ -848,6 +849,7 @@ sub render_row {
 			$rb->text($v, $base_pen);
 		}
 		$rb->erase($post, $base_pen) if $post;
+		$rb->erase_to($col < $#$data ? $self->{columns}[$col + 1]->{start} : $self->body_cols, $base_pen);
 	}
 }
 
@@ -969,7 +971,7 @@ sub row_cache {
 			# object, hashref, arrayref... the item transformations will
 			# convert it into something usable
 			my ($item) = @{ $_[0] };
-			return Future->fail('no such element') unless $item;
+			return Future->fail('no such element', table => not_found => $row) unless $item;
 
 			# Somewhat tedious way to reduce() a Future chain
 			$self->fold_future([ $row ], $item, @{$self->{item_transformations}})
